@@ -1,9 +1,9 @@
 import numpy as np
 import matplotlib.pyplot as plt
-from numpy.core.shape_base import block
-import PyFWI.seismic_io as io
 
 from PyFWI.seiplot import seismic_section
+import PyFWI.seismic_io as io
+
 
 class Gain():
 
@@ -69,7 +69,7 @@ class Gain():
         ax.set_xlabel("Gain amplitude")
         ax.set_ylabel("Time sample")
 
-class Gain_function(Gain):
+class GainFunction(Gain):
     def __init__(self, t, dt, nt):
         """
         This class works with the choosen gain
@@ -77,7 +77,7 @@ class Gain_function(Gain):
         This class gets the gain function and apply it
 
         Args:
-            gain_function (float32): The gain function
+            GainFunction (float32): The gain function
         """
         Gain.__init__(self, t, dt, nt)
 
@@ -98,11 +98,11 @@ class Gain_function(Gain):
         gain = self.gain_function.reshape(-1,1)
         
         if type(data).__name__ == 'list':
-            self.gain_2d = gain @ np.ones((1, data[0].shape[1]), np.float32)
+            self.gain_2d = np.dot(gain, np.ones((1, data[0].shape[1]), np.float32))
             self.gained_data = [self.gain_2d * comp_i for comp_i in data]
             
         elif type(data).__name__ == 'ndarray':
-            self.gain_2d = gain @ np.ones((1, data.shape[1]), np.float32)
+            self.gain_2d = np.dot(gain, np.ones((1, data.shape[1]), np.float32))
             self.gained_data = self.gain_2d *  data
 
         
@@ -121,7 +121,7 @@ class Gain_function(Gain):
 if __name__ == "__main__":
     data = io.load_mat('/Users/amir/repos/seismic/src/PyFWI/data/test/bl_data.mat')
     data = data['bl']
-    G = Gain_function(t=0.45, dt=0.00061, nt=data.shape[0])
+    G = GainFunction(t=0.45, dt=0.00061, nt=data.shape[0])
     G.time_linear(False)
     plt.show()
     
