@@ -17,7 +17,7 @@ from PyFWI.grad_swithcher import grad_lmd_to_vd
 
 class WavePreparation:
 
-    def __init__(self, inpa, src, rec_loc, model_shape, n_well_rec=0, chpr=10, components=0):
+    def __init__(self, inpa, src, rec_loc, model_shape, n_well_rec=0, chpr=10, components=0, set_env_variable=True):
         '''
         A class to prepare the variable and basic functions for wave propagation.
 
@@ -25,6 +25,8 @@ class WavePreparation:
         #TODO: work on how ypu specify the acq_type, getting n_well_rec, using that again fpr two .cl files
         keys = [*inpa]
 
+        self.set_env_variable = set_env_variable
+        
         self.t = inpa['t']
         self.dt = inpa['dt']
         self.nt = int(1 + self.t // self.dt)
@@ -146,22 +148,22 @@ class WavePreparation:
             platform = 0
 
         # Choose th device (pick 0 if not provided)
-        devices = get_test_platforms_and_devices()[0][1]
+        devices = get_test_platforms_and_devices()[0][1] # (platforms, devices)
         if "device" in keys:
             device = inpa["device"]
             if device >= len(devices):
                 raise Exception("Bad chosen device. There are {} available device(s).".format(len(devices)))
         else:
             device = 0
-            # print("Device {} is chosen.".format(device))
-
-        os.environ['PYOPENCL_CTX'] = str(platform) + ':' + str(device)
-        os.environ['PYOPENCL_COMPILER_OUTPUT'] = '1'
-
+            print("Device {} is chosen.".format(device))
 
+        if set_env_variable:
+            os.environ['PYOPENCL_CTX'] = str(platform) + ':' + str(device)
+            os.environ['PYOPENCL_COMPILER_OUTPUT'] = '1'
+        
         self.ctx = cl.create_some_context()
         self.queue = cl.CommandQueue(self.ctx)
-
+        
         kernel, kernel_crosswell, kernel_surface = self.kernel_caller()
 
         self.prg_cw = cl.Program(self.ctx, kernel_crosswell).build()
@@ -599,8 +601,9 @@ class WavePropagator(WavePreparation):
     component:
         Seismic output
     """
-    def __init__(self, inpa, src, rec_loc, model_shape, n_well_rec=None, chpr=10, components=0):
-        WavePreparation.__init__(self, inpa, src, rec_loc, model_shape, n_well_rec, chpr=chpr, components=components)
+    def __init__(self, inpa, src, rec_loc, model_shape, n_well_rec=None, chpr=10, components=0, set_env_variable=True):
+        WavePreparation.__init__(self, inpa, src, rec_loc, model_shape, n_well_rec, chpr=chpr,
+                                 components=components, set_env_variable=set_env_variable)
 
     def forward_propagator(self, model):
         """ This function is in charge of forward modelling for acoustic case
@@ -924,7 +927,7 @@ if __name__ == "__main__":
     inpa['npml'] = 20
     inpa['pmlR'] = 1e-5
     inpa['pml_dir'] = 2
-    inpa['device'] = 1
+    # inpa['device'] = 0
     inpa['energy_balancing'] = False
     inpa['seisout'] = 0
 
